6950022 X man page cleanups nv_140
authorAlan Coopersmith <Alan.Coopersmith@Oracle.COM>
Wed, 05 May 2010 14:06:42 -0700
changeset 947 ef9da9d336f5
parent 946 c4381a29a60a
child 948 f51b35a0610f
6950022 X man page cleanups
open-src/app/transset/Makefile
open-src/app/xcompmgr/Makefile
open-src/app/xedit/Makefile
open-src/app/xfs/Makefile
open-src/app/xrx/Makefile
open-src/common/Makefile.inc
open-src/common/suntouch-manpages.pl
open-src/driver/xf86-video-openchrome/Makefile
open-src/driver/xf86-video-openchrome/manpage-sections.patch
open-src/driver/xf86-video-s3/Makefile
open-src/driver/xf86-video-wsfb/Makefile
open-src/lib/fontconfig/Makefile
open-src/lib/libICE/Makefile
open-src/lib/libSM/Makefile
open-src/lib/libXau/Makefile
open-src/lib/libXdmcp/Makefile
open-src/lib/libXt/Makefile
open-src/xserver/Makefile.inc
open-src/xserver/xorg/Makefile
open-src/xserver/xvnc/Makefile
packages/SUNWxorg-graphics-ddx/prototype_i386
--- a/open-src/app/transset/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/app/transset/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -40,8 +40,8 @@
 SOURCE_URL_SET=yes
 
 # Man pages to apply Sun footer to & attributes to list
-#SUNTOUCHED_MANPAGES=man/*.man
-SUN_PACKAGE=SUNWcompmgr
+SUNTOUCHED_MANPAGES=transset.1
+SUN_PACKAGE=SUNWxcompmgr
 MODULE_STABILITY=Volatile
 
 include ../Makefile.inc
--- a/open-src/app/xcompmgr/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/app/xcompmgr/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -37,7 +37,7 @@
 
 
 # Man pages to apply Sun footer to & attributes to list
-#SUNTOUCHED_MANPAGES=man/*.man
+SUNTOUCHED_MANPAGES=xcompmgr.1
 SUN_PACKAGE=SUNWxcompmgr
 MODULE_STABILITY=Volatile
 
--- a/open-src/app/xedit/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/app/xedit/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -40,7 +40,7 @@
 
 # Man pages to apply Sun footer to & attributes to list
 SUNTOUCHED_MANPAGES=*.man
-SUNTOUCH_MAN_FLAGS= \
- -a '{Availability, SUNWxwopt} {Interface Stability, Committed}'
+SUN_PACKAGE=SUNWxwopt
+MODULE_STABILITY=Committed
 
 include ../Makefile.inc
--- a/open-src/app/xfs/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/app/xfs/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -70,6 +70,6 @@
 
 install_fsadmin:
 	mkdir -p $(PROTODIR)$(X11_DIR)/sbin \
-		$(PROTODIR)$(X11_MAN_DIR)/man/man1
+		$(PROTODIR)$(X11_MAN_DIR)/man1
 	$(INSTALL_SCRIPT) -m 0755 fsadmin $(PROTODIR)$(X11_DIR)/sbin
 	$(INSTALL_SCRIPT) fsadmin.1 $(PROTODIR)$(X11_MAN_DIR)/man1
--- a/open-src/app/xrx/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/app/xrx/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -39,7 +39,7 @@
 SOURCE_PATCHES= 
 
 # Man pages to apply Sun footer to & attributes to list
-SUNTOUCHED_MANPAGES=*/*.man
+SUNTOUCHED_MANPAGES=helper/xrx.man plugin/libxrx.man
 SUN_PACKAGE=SUNWxwopt
 MODULE_STABILITY=Committed
 
--- a/open-src/common/Makefile.inc	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/common/Makefile.inc	Wed May 05 14:06:42 2010 -0700
@@ -348,26 +348,26 @@
 	touch $(PATCHED_TARGET)
 
 # Step 4: Apply common Solaris changes to man pages in $(SUNTOUCHED_MANPAGES)
-FIXED_MAN_TARGET_FILE=.mantouch.done
-FIXED_MAN_TARGET=$(SOURCE_DIR)/$(FIXED_MAN_TARGET_FILE)
+FIXED_MAN_SUFFIX=mantouch.done
+FIXED_MAN_TARGET=$(SUNTOUCHED_MANPAGES:%=$(SOURCE_DIR)/%.$(FIXED_MAN_SUFFIX))
 fixed_man: $(FIXED_MAN_TARGET)
 
 COMMON_SUNTOUCH_MAN_FLAGS = \
 	-a '{Availability, $(SUN_PACKAGE)}' \
 	-a '{Interface Stability, $(MODULE_STABILITY)}'
 
-SUNTOUCH_MAN_FLAGS = \
+DEFAULT_SUNTOUCH_MAN_FLAGS = \
 	$(COMMON_SUNTOUCH_MAN_FLAGS) \
 	$(MODTYPE_SUNTOUCH_MAN_FLAGS) \
 	$(MODULE_SUNTOUCH_MAN_FLAGS)
 
-$(FIXED_MAN_TARGET): $(PATCHED_TARGET)
-	@if [[ "$(SUNTOUCHED_MANPAGES)" != "" ]] ; then \
-	    $(START_CMD_ECHO) ; \
-	    $(PERL) $(TOP)/common/suntouch-manpages.pl $(SUNTOUCH_MAN_FLAGS) \
-		$(SUNTOUCHED_MANPAGES:%=$(SOURCE_DIR)/%) ; \
-	fi
-	touch $(FIXED_MAN_TARGET)
+SUNTOUCH_MAN_FLAGS_DEFAULT	= $(SUNTOUCH_MAN_FLAGS_SET:yes=$(POUND_SIGN))
+$(SUNTOUCH_MAN_FLAGS_DEFAULT)	SUNTOUCH_MAN_FLAGS = $(DEFAULT_SUNTOUCH_MAN_FLAGS)
+
+$(FIXED_MAN_TARGET): $(PATCHED_TARGET) $(SOURCE_ADD_TARGET)
+	$(PERL) $(TOP)/common/suntouch-manpages.pl $(SUNTOUCH_MAN_FLAGS) \
+		$(@:%.$(FIXED_MAN_SUFFIX)=%)
+	touch $@
 
 # Step 5: Apply common Solaris changes to pkg-config *.pc files listed in
 # $(FIX_PC_FILES)
--- a/open-src/driver/xf86-video-openchrome/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/driver/xf86-video-openchrome/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -36,7 +36,10 @@
 TARBALL_SHA1 = 23225057d5b75d6aac3e7a710cbc067b2eb29228
 
 # Patches to apply to source after unpacking, in order
-SOURCE_PATCHES =
+SOURCE_PATCHES = manpage-sections.patch,-p1
+
+# manpage-sections.patch edits configure.ac, so we need to autoreconf
+AUTORECONF=yes
 
 # Man pages to apply Sun footer to & attributes to list
 SUNTOUCHED_MANPAGES=man/*.man
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/open-src/driver/xf86-video-openchrome/manpage-sections.patch	Wed May 05 14:06:42 2010 -0700
@@ -0,0 +1,15 @@
+Use XORG_MANPAGE_SECTIONS to get the right OS-specific man page sections
+instead of the hardcoded Linux/BSD sections that don't match SysV/Solaris.
+
+--- xf86-video-openchrome-0.2.904/configure.ac	Wed Oct  7 16:41:12 2009
++++ xf86-video-openchrome-0.2.904/configure.ac	Thu Apr  8 15:11:06 2010
+@@ -169,8 +169,7 @@
+ AC_DEFINE(X_HAVE_XAAGETROP,1,[Compatibility define for older Xen])
+ AC_DEFINE(X_NEED_I2CSTART,1,[Compatibility define for older Xen])
+ 
+-DRIVER_MAN_SUFFIX="4"
+-AC_SUBST([DRIVER_MAN_SUFFIX])
++XORG_MANPAGE_SECTIONS
+ 
+ XORG_RELEASE_VERSION
+ 
--- a/open-src/driver/xf86-video-s3/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/driver/xf86-video-s3/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -39,7 +39,7 @@
 SOURCE_PATCHES = 
 
 # Man pages to apply Sun footer to & attributes to list
-#SUNTOUCHED_MANPAGES=man/*.man
+SUNTOUCHED_MANPAGES=man/*.man
 SUN_PACKAGE=SUNWxorg-graphics-ddx
 MODULE_STABILITY=Volatile
 
--- a/open-src/driver/xf86-video-wsfb/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/driver/xf86-video-wsfb/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -41,7 +41,7 @@
 
 
 # Man pages to apply Sun footer to & attributes to list
-#SUNTOUCHED_MANPAGES=man/*.man
+SUNTOUCHED_MANPAGES=man/*.man
 SUN_PACKAGE=SUNWxorg-graphics-ddx
 MODULE_STABILITY=Volatile
 
--- a/open-src/lib/fontconfig/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/fontconfig/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -53,12 +53,28 @@
 LIBNAME=fontconfig
 
 # Man pages to apply Sun footer to & attributes to list
-SUNTOUCHED_MANPAGES=*/*.1 doc/*.3 doc/*.5
+FONTCONFIG_CMDS = fc-cache fc-list fc-query fc-cat fc-match fc-scan
+SUNTOUCHED_MANPAGES = $(FONTCONFIG_CMDS:%=%/%.1) doc/*.3 doc/*.5
 SUN_PACKAGE=SUNWfontconfig
 MODULE_STABILITY=Volatile
 LIB_MAN_SUFFIX=3fontconfig
 MODULE_MTLEVEL=Unknown
-MODULE_MTLEVEL_set=yes
+MODULE_MTLEVEL_SET=yes
+
+# Override specific attributes for specific man pages
+SUNTOUCH_MAN_FLAGS = $(COMMON_SUNTOUCH_MAN_FLAGS) \
+	$(SUNTOUCH_MAN_FLAGS_$(@F:%.$(FIXED_MAN_SUFFIX)=%))
+SUNTOUCH_MAN_FLAGS_SET = yes
+# API docs are in doc/*.3
+SUNTOUCH_MAN_FLAGS_*.3 = $(MODTYPE_SUNTOUCH_MAN_FLAGS)
+# Command docs are in per-command dirs
+SUNTOUCH_MAN_FLAGS_CMDS = -p $(MODULE_PREFIX)/bin/
+SUNTOUCH_MAN_FLAGS_fc-cache.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
+SUNTOUCH_MAN_FLAGS_fc-list.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
+SUNTOUCH_MAN_FLAGS_fc-query.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
+SUNTOUCH_MAN_FLAGS_fc-cat.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
+SUNTOUCH_MAN_FLAGS_fc-match.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
+SUNTOUCH_MAN_FLAGS_fc-scan.1	= $(SUNTOUCH_MAN_FLAGS_CMDS)
 
 # Install to /usr, not /usr/X11
 MODULE_PREFIX=/usr
--- a/open-src/lib/libICE/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/libICE/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -46,6 +46,7 @@
 SUN_PACKAGE=SUNWxwice
 MODULE_STABILITY=Committed
 MODULE_MTLEVEL=Unsafe
+MODULE_MTLEVEL_SET=yes
 LIB_MAN_SUFFIX=3ICE
 
 # Command line options to GNU autoconf configure script
--- a/open-src/lib/libSM/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/libSM/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -46,6 +46,7 @@
 SUN_PACKAGE=SUNWxwplt
 MODULE_STABILITY=Committed
 MODULE_MTLEVEL=Unsafe
+MODULE_MTLEVEL_SET=yes
 LIB_MAN_SUFFIX=3SM
 
 # Command line options to GNU autoconf configure script
--- a/open-src/lib/libXau/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/libXau/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -45,8 +45,9 @@
 SUNTOUCHED_MANPAGES=Xau.man
 SUN_PACKAGE=SUNWxwplt
 MODULE_STABILITY=Committed
+MODULE_MTLEVEL=Unsafe
+MODULE_MTLEVEL_SET=yes
 LIB_MAN_SUFFIX=3Xau
-LIB_SUNTOUCH_MAN_FLAGS= -a '{Availability, $(SUN_PACKAGE)} {Interface Stability, $(MODULE_STABILITY)} {MT-Level, Unsafe}'
 
 # Command line options to GNU autoconf configure script
 MODULE_CONFIG_OPTS = --enable-xthreads --with-lint --enable-lint-library
--- a/open-src/lib/libXdmcp/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/libXdmcp/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -47,6 +47,7 @@
 MODULE_STABILITY=Committed
 LIB_MAN_SUFFIX=3Xdmcp
 MODULE_MTLEVEL=Unsafe
+MODULE_MTLEVEL_SET=yes
 
 # Link with version mapfile
 MODULE_LD_OPTIONS = -M $(PWD)/mapfile-vers
--- a/open-src/lib/libXt/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/lib/libXt/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -51,6 +51,8 @@
 SUNTOUCHED_MANPAGES=man/*.man
 SUN_PACKAGE=SUNWxwplt
 MODULE_STABILITY=Committed
+MODULE_MTLEVEL=See XtToolkitThreadInitialize(3Xt)
+MODULE_MTLEVEL_SET=yes
 LIB_MAN_SUFFIX=3Xt
 
 
--- a/open-src/xserver/Makefile.inc	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/xserver/Makefile.inc	Wed May 05 14:06:42 2010 -0700
@@ -40,6 +40,9 @@
 SERVER_MODULES_DIR='$(X11_SERVERMODS_DIR)$(SERVERMOD_subdir)'
 DRI_MODULES_DIR='$(X11_SERVERMODS_DIR)/dri$(SERVERMOD_subdir)'
 
+# Changes to apply to man pages
+MODTYPE_SUNTOUCH_MAN_FLAGS= -p $(MODULE_PREFIX)/bin/
+
 # Command line options to GNU autoconf configure script for xorg-server
 XSERVER_CONFIG_OPTS_COMMON = \
 	--bindir='$${exec_prefix}/bin/$(ARCHBINSUBDIR)' \
--- a/open-src/xserver/xorg/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/xserver/xorg/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -61,7 +61,6 @@
 
 SUN_PACKAGE=SUNWxorg-server
 MODULE_STABILITY=Volatile
-MODULE_SUNTOUCH_MAN_FLAGS= -p $(MODULE_PREFIX)/bin/
 
 # Binary built in tree
 XORGSERVER_BIN=$(SOURCE_DIR)/hw/xfree86/Xorg
--- a/open-src/xserver/xvnc/Makefile	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/xserver/xvnc/Makefile	Wed May 05 14:06:42 2010 -0700
@@ -66,14 +66,23 @@
 	upstream-modkeystick.patch,-p0 \
 	solaris-port.patch
 
+
 # Man pages to apply Sun footer to & attributes to list
-# Common ones are here - Xvnc_source_fini target below has more with
-# different attributes/path set
 SUNTOUCHED_MANPAGES= \
+	unix/xserver/hw/vnc/Xvnc.man unix/vncviewer/vncviewer.man \
 	unix/vncconfig/vncconfig.man unix/vncpasswd/vncpasswd.man \
 	unix/vncserver.man unix/x0vncserver/x0vncserver.man
-SUNTOUCH_MAN_FLAGS= -p /usr/bin/ \
- -a '{Availability, SUNWxvnc} {Interface Stability, Volatile}'
+SUN_PACKAGE = SUNWxvnc
+MODULE_STABILITY = Volatile
+
+# Additional package name used for vncviewer package
+VNCVIEWER_PKGNAME=SUNWvncviewer
+
+# Override specific attributes for specific man pages
+MODULE_SUNTOUCH_MAN_FLAGS= \
+	$(SUNTOUCH_MAN_FLAGS_$(@F:%.man.$(FIXED_MAN_SUFFIX)=%))
+SUNTOUCH_MAN_FLAGS_vncviewer = -o '{Availability, $(VNCVIEWER_PKGNAME)}' \
+	-o '{Interface Stability, Path: Committed, Options: Volatile}'
 
 # Compiler to use
 MODULE_COMPILER=suncc
@@ -81,8 +90,8 @@
 
 # Xvnc has to configure, build, and install in different directories due to 
 # the mixed codebases and unusual directory layout
-MODULE_ADD_SOURCE_TARGETS=Xvnc_source_init Xvnc_source_fini
-MODULE_SOURCE_DEPS=Xvnc_source_init
+MODULE_ADD_SOURCE_TARGETS=Xvnc_source_init
+MODULE_SOURCE_DEPS = Xvnc_source_init
 CONFIGURE_TARGETS=$(SOURCE_DIR)/unix/Makefile $(XORG_BUILD_DIR)/Makefile
 CONFIGURE_TARGETS_SET=yes
 BUILD_TARGETS_common=Xvnc_build set-elf-comments
@@ -128,16 +137,6 @@
 		SOURCE_PATCHES="$(XORG_SOURCE_PATCHES:%=../xorg/%)" \
 		SOURCE_DIR="$(XORG_BUILD_DIR)"
 
-# Apply specific sets of Solaris attributes to various man pages
-# This step has to be done after default_source, since it depends
-# on files created in that stage
-Xvnc_source_fini: $(UNPACK_TARGET)
-	$(PERL) $(TOP)/common/suntouch-manpages.pl \
-	  -a '{Availability, SUNWvncviewer} {Interface Stability, Volatile}' \
-	  -p /usr/bin/ $(SOURCE_DIR)/unix/vncviewer/vncviewer.man
-	$(PERL) $(TOP)/common/suntouch-manpages.pl \
-	  -a '{Availability, SUNWxvnc} {Interface Stability, Volatile}' \
-	  -p $(X11_DIR)/bin/ $(SOURCE_DIR)/unix/xserver/hw/vnc/Xvnc.man
 
 # Command line options to GNU autoconf configure script for vnc clients
 VNC_CONFIG_OPTS= --with-installed-zlib --prefix=/usr \
--- a/packages/SUNWxorg-graphics-ddx/prototype_i386	Tue May 04 15:58:18 2010 -0700
+++ b/packages/SUNWxorg-graphics-ddx/prototype_i386	Wed May 05 14:06:42 2010 -0700
@@ -164,11 +164,12 @@
 f none share/man/man7/mga.7					0444 root bin
 f none share/man/man7/neomagic.7				0444 root bin
 f none share/man/man7/nv.7					0444 root bin
-f none share/man/man7/openchrome.7=$HOME/share/man/man4/openchrome.4	0444 root bin
+f none share/man/man7/openchrome.7				0444 root bin
 f none share/man/man7/r128.7					0444 root bin
 f none share/man/man7/radeon.7					0444 root bin
 f none share/man/man7/radeonhd.7				0444 root bin
 f none share/man/man7/rendition.7				0444 root bin
+f none share/man/man7/s3.7					0444 root bin
 f none share/man/man7/s3virge.7					0444 root bin
 f none share/man/man7/savage.7					0444 root bin
 f none share/man/man7/siliconmotion.7				0444 root bin
--- a/open-src/common/suntouch-manpages.pl	Tue May 04 15:58:18 2010 -0700
+++ b/open-src/common/suntouch-manpages.pl	Wed May 05 14:06:42 2010 -0700
@@ -1,7 +1,7 @@
 #!/usr/perl5/bin/perl -w
 
 #
-# Copyright (c) 2006, 2008, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2006, 2010, Oracle and/or its affiliates. All rights reserved.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
@@ -26,8 +26,10 @@
 
 # Updates manual pages to include standard Sun man page sections
 #
 # Arguments: 
 #	-a '{attribute, value}, ...' - entries for Attributes section table
 #	-l libname		     - add library line to synopsis
 #	-p path			     - add path to command in synopsis
 
@@ -36,16 +38,18 @@
 use strict;
 
 my @attributes;
+my @overrides;
 my $library;
 my $synpath;
 
 my $result = GetOptions('a|attribute=s' => \@attributes,
+			'o|override=s'  => \@overrides,
 			'l|library=s'	=> \$library,
 			'p|path=s'	=> \$synpath);
 
 my $add_attributes = 0;
 
-if (scalar(@attributes) > 0) {
+if (scalar(@attributes) + scalar(@overrides) > 0) {
   $add_attributes = 1;
 }
 
@@ -64,12 +68,12 @@
 my $filename;
 
 while ($filename = shift) {
-  rename($filename, "$filename.orig") 
-    || die "Cannot rename $filename to $filename.orig";
-  open(IN, "<$filename.orig") 
-    || die "Cannot read $filename.orig";
-  open(OUT, ">$filename")
-    || die "Cannot write to $filename";
+  rename($filename, "$filename.orig")
+    || die "Cannot rename $filename to $filename.orig: $!";
+  open(IN, '<', "$filename.orig")
+    || die "Cannot read $filename.orig: $!";
+  open(OUT, '>', $filename)
+    || die "Cannot write to $filename: $!";
 
   my $firstline = <IN>;
 
@@ -113,7 +117,7 @@
   }
 
   if ($add_attributes) {
-    print OUT &get_attributes_table(join(" ", @attributes));
+    print OUT &get_attributes_table(\@attributes, \@overrides);
   }
 
   close(IN);
@@ -122,7 +126,7 @@
 
 
 sub get_attributes_table {
-  my $attribute_list = $_[0];
+  my ($attributes_ref, $overrides_ref) = @_;
 
   my $attributes_table = q{
 .\\" Begin Sun update
@@ -135,22 +139,34 @@
 lw(2.750000i)| lw(2.750000i).
 ATTRIBUTE TYPE	ATTRIBUTE VALUE
 <attributes>
-.TE 
+.TE
 .sp
 .\\" End Sun update
 };
 
-  # Parse input list of attributes
-  $attribute_list =~ s/^\s*{//;
-  $attribute_list =~ s/}\s*$//;
-  my @attribs = split /}\s*{/, $attribute_list;
-
-  my $a;
   my $attribute_entries = "";
 
-  foreach $a (@attribs) {
-    my ($name, $value) = split /,\s*/, $a, 2;
+  my @attribute_pairs = parse_attributes_list($attributes_ref);
+  my @overrides_pairs = parse_attributes_list($overrides_ref);
+
+  foreach my $o (@overrides_pairs) {
+    my ($oname, $ovalue) = @{$o};
+    my $found_match = 0;
 
+    foreach my $a (@attribute_pairs) {
+      if ($a->[0] eq $oname) {
+	$a->[1] = $ovalue;
+	$found_match++;
+      }
+    }
+
+    if ($found_match == 0) {
+      push @attribute_pairs, $o;
+    }
+  }
+
+  foreach my $a (@attribute_pairs) {
+    my ($name, $value) = @{$a};
     $attribute_entries .= $name . "\t" . $value . "\n";
   }
 
@@ -158,3 +174,20 @@
 
   return $attributes_table;
 }
+
+sub parse_attributes_list {
+  my ($list_ref) = @_;
+
+  my $list_string = join(" ", @{$list_ref});
+  $list_string =~ s/^\s*{//;
+  $list_string =~ s/}\s*$//;
+
+  my @attribs = split /}\s*{/, $list_string;
+  my @attrib_pairs = ();
+
+  foreach my $a (@attribs) {
+    my @pair = split /,\s*/, $a, 2;  # pair = name, value
+    push @attrib_pairs, \@pair;
+  }
+  return @attrib_pairs;
+}
@@ -26,8 +26,10 @@
 # Updates manual pages to include standard Sun man page sections
 #
-# Arguments: 
-#	-a '{attribute, value}, ...' - entries for Attributes section table
+# Arguments:
+#	-a '{attribute, value}, ...' - add entries to Attributes section table
+#	-o '{attribute, value}, ...' - override previous entries in
+#					Attributes section table
 #	-l libname		     - add library line to synopsis
 #	-p path			     - add path to command in synopsis